#!/bin/sh
# To-Do: select X and Y range on cmdline
outfile=
outdev=x11
title="Histogram of times for each MPI send+recv exchange iteration"
xrange=":"
yrange=":"
xlabel="useconds"
ylabel="no. of iterations"
pstyle=histeps
usage="Usage: $0 [-d] [-123456789] [-n PLOTNUM] [-o outfile] [-p] [-s plotstyle] [-t title] [-T terminal] [-x xmin:xmax] [-y ymin:ymax] [-X X-axis-label] [-Y Y-axis-label] file...
	-d for debug
	-1..9 selects the appropriate plot from all files, same as -n 1 to -n 9
	-n PLOTNUM selects the PLOTNUM plot from all files
	-p sets output type to color postscript, requires -o outputfile
	-s sets style of plot, default $ptype
	-T sets output type to some other terminal, may need -o outputfile
	-x xmin:xmax sets X range, can skip either or both of xmin and xmax,
	   just : means autorange, default is $xrange
	-y ymin:ymax sets Y range
"
while getopts 123456789dhn:o:ps:t:T:x:y:X:Y: c
do
	case $c in
	d)	debug=y;;
	[0-9])	index="index $c";;
	n)	index="index $OPTARG";;
	o)	outfile="$OPTARG";;
	p)	outdev="postscript eps color solid";;
	s)	pstyle="$OPTARG";;
	t)	title="$OPTARG";;
	T)	outdev="$OPTARG";;
	x)	xrange="$OPTARG";;
	y)	yrange="$OPTARG";;
	X)	xlabel="$OPTARG";;
	Y)	ylabel="$OPTARG";;
	*) 	echo "$usage" >&2; exit 2;;
	esac
done
shift `expr $OPTIND - 1`

tmp="/tmp/gp$$"
cat << EOF >> $tmp
set title '$title'
set logscale xy
set xrange [$xrange]
set yrange [$yrange]
set xlabel '$xlabel'
set ylabel '$ylabel'
set terminal $outdev
EOF
case "$outfile" in
'')	;;
*)	echo "set output '$outfile'" >> $tmp;;
esac
s="plot"
sep=""
for i
do
	title=`expr "$i" : ".*/\([^/]*/[^/]*\)"`
	case "$title" in
	'')	title="$i";;
	esac
	s="$s$sep '$i' $index title '$title' with $pstyle"
	sep=","
done
(echo "$s";  echo 'pause -1 "Hit Return to exit"') >> $tmp
gnuplot $tmp
rm "$tmp"
